import { ISourceDataRowBase, ISourceDataRowBaseCore } from '../../types';
import { GraphQLFieldConfigMap } from 'graphql/type/definition';
/**
 * Get a list of GraphQL fields from a list of entities
 *
 * @example
 * const entities = [
 *     {
 *         "id": 1,
 *         "title": "Lorem Ipsum",
 *         "views": 254,
 *         "user_id": 123,
 *     },
 *     {
 *         "id": 2,
 *         "title": "Sic Dolor amet",
 *         "user_id": 456,
 *     },
 * ];
 * const types = getFieldsFromEntities(entities);
 * // {
 * //    id: { type: new GraphQLNonNull(GraphQLString) },
 * //    title: { type: new GraphQLNonNull(GraphQLString) },
 * //    views: { type: GraphQLInt },
 * //    user_id: { type: new GraphQLNonNull(GraphQLString) },
 * // };
 */
export default function getFieldsFromEntities<T extends ISourceDataRowBaseCore = ISourceDataRowBase>(keyNames: string[], entities: T[], checkRequired?: boolean): GraphQLFieldConfigMap<any, any, {
    [key: string]: any;
}>;
